@@ -1,7 +1,8 @@
 GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, ylabel = NA,
                       size = 1.1, grid = TRUE, color = TRUE, linlab = NA, class = NA,  
                       classcolor = NA, posleg = 2, boxleg = TRUE, axesvar = TRUE, 
-                      axes = TRUE, numrot = 200, choicerot = NA, savepicture = FALSE) {
+                      axes = TRUE, numrot = 200, choicerot = NA, savptc = FALSE, 
+                      width = 3236, height = 2000, res = 300) {
   
   # Esta funcao executa a rotacao dos dados multivariados em baixa dimensao
   # basea-se nos artigos de: Asimov, D. . The Grand Tour: A Tool for Viewing
@@ -39,8 +40,11 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
   # numrot  - Numero de rotacoes (default = 200).
   #           Se method = "Interpolation", numrot representara o angulo de rotacao.
   # choicerot - Escolhe rotacao especifica e apresenta na tela,
-  #             ou salva a imagem se savepicture = TRUE.
-  # savepicture - Salva as imagens dos graficos em arquivos (default = FALSE).
+  #             ou salva a imagem se savptc = TRUE.
+  # savptc - Salva as imagens dos graficos em arquivos (default = FALSE).
+  # width  - Largura do grafico quanto savptc = TRUE (defaul = 3236).
+  # height - Altura do grafico quanto savptc = TRUE (default = 2000).
+  # res    - Resolucao nominal em ppi do grafico quanto savptc = TRUE (default = 300).
   
   # Retorna:
   # Graficos com as rotacoes.
@@ -102,8 +106,17 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         stop("numrot < choicerot, numrot should be greater than or equal to choicerot. Verify!")
   }
 
-  if (!is.logical(savepicture))
-     stop("'savepicture' input is incorrect, it should be TRUE or FALSE. Verify!")
+  if (!is.logical(savptc))
+     stop("'savptc' input is incorrect, it should be TRUE or FALSE. Verify!")
+
+  if (!is.numeric(width) || width <= 0)
+     stop("'width' input is incorrect, it should be numerical and greater than zero. Verify!")
+  
+  if (!is.numeric(height) || height <= 0)
+     stop("'height' input is incorrect, it should be numerical and greater than zero. Verify!")
+  
+  if (!is.numeric(res) || res <= 0)
+     stop("'res' input is incorrect, it should be numerical and greater than zero. Verify!")
   
   if (!is.character(xlabel) && !is.na(xlabel[1]))
      stop("'xlabel' input is incorrect, it should be of type character or string. Verify!")
@@ -112,10 +125,10 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
      stop("'ylabel' input is incorrect, it should be of type character or string. Verify!")
   
   if (is.na(xlabel[1]))
-     xlabel = "X-Axis" 
+     xlabel = "X-axis" 
   
   if (is.na(ylabel[1]))
-     ylabel = "Y-Axis"
+     ylabel = "Y-axis"
 
   if (posleg==1) posleg = "topleft"   # posicao das legendas nos graficos
   if (posleg==2) posleg = "topright"
@@ -128,7 +141,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
   
   Num.class = 0
   if (!is.na(class[1])) {
-    class.Table <- table(class)       # cria tabela com as quantidade dos elementos das classes
+    class.Table <- table(class)        # cria tabela com as quantidade dos elementos das classes
     class.Names <- names(class.Table)  # nomes das classses
     Num.class   <- length(class.Table) # numero de classes
     NomeLinhas  <- as.matrix(class)
@@ -164,9 +177,9 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     
     numrot <- ifelse(is.na(choicerot[1]), numrot, choicerot)
     
-    if (savepicture) {
-      cat("\014") # limpa a tela
-      cat("\n\n Saving graphics to hard disk. Wait for the end!")
+    if (savptc) {
+      message("\014") # limpa a tela
+      message("\n\n Saving graphics to hard disk. Wait for the end!")
     }
     
     i <- 1
@@ -194,7 +207,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
       if (is.na(choicerot[1]) || choicerot == i) {
         
-        if (savepicture) png(filename = paste("Picture ", i," - Method", method,".png",step="")) # salva os graficos em arquivos
+        if (savptc) png(filename = paste("Picture_", i,"-Method_", method,".png",sep=""), width = width, height = height, res = res) # salva os graficos em arquivos
         
         maxX = max(proj.data[, 1], A[,1])
         minX = min(proj.data[, 1], A[,1])
@@ -208,28 +221,27 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         }
         else { cor.classe <- c("blue") }
         
+        plot(proj.data, # coordenadas do grafico
+             xlab = xlabel, # Nomeia Eixo X
+             ylab = ylabel, # Nomeia Eixo Y
+             type = "n",    # nao plota pontos
+             main = Tit,    # Titulo para o grafico
+             xlim = c(minX,maxX), # dimensao eixo X
+             ylim = c(minY,maxY)) # dimensao eixo Y
+        
+        if (grid) {
+          
+          args <- append(as.list(par('usr')), c('gray93','gray93'))
+          
+          names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
+          
+          do.call(rect, args) # chama a funcao rect com os argumentos (args)
+          
+          grid(col = "white", lwd = 2, lty = 7, equilogs = T)
+          
+        }
+        
         if (Num.class == 0) {
-          
-           plot(proj.data, # coordenadas do grafico
-                xlab = xlabel, # Nomeia Eixo X
-                ylab = ylabel, # Nomeia Eixo Y
-                type = "n",    # nao plota pontos
-                main = Tit,    # Titulo para o grafico
-                xlim = c(minX,maxX), # dimensao eixo X
-                ylim = c(minY,maxY)) # dimensao eixo Y
-          
-           if (grid) {
-            
-              args <- append(as.list(par('usr')), c('gray93','gray93'))
-             
-              names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
-             
-              do.call(rect, args) # chama a funcao rect com os argumentos (args)
-             
-              grid(col = "white", lwd = 2, lty = 7, equilogs = T)
-            
-           }
-          
            points(proj.data, # coordenadas do grafico
                   pch  = 16,  # formato dos pontos
                   cex = size,  # Tamanho dos pontos 
@@ -237,27 +249,6 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
           
         } else {
           
-          plot(0,0, # cria grafico para as coordenadas linhas x e colunas y
-               xlab = xlabel, # Nomeia Eixo X
-               ylab = ylabel, # Nomeia Eixo Y
-               main = Tit,    # Titulo
-               type = "n",    # nao plota pontos
-               xlim = c(minX,maxX), # dimensao eixo X
-               ylim = c(minY,maxY), # dimensao eixo Y
-               col  = ifelse(color,"red","black"))  # Cor dos pontos
-          
-          if (grid) {
-            
-             args <- append(as.list(par('usr')), c('gray93','gray93'))
-            
-             names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
-            
-             do.call(rect, args) # chama a funcao rect com os argumentos (args)
-            
-             grid(col = "white", lwd = 2, lty = 7, equilogs = T)
-            
-          } 
-          
           Init.Form <- 14 # formato inicial dos pontos
           
           for (k in 1:Num.class) {
@@ -281,8 +272,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         
         if (!is.na(linlab[1])) LocLab(proj.data, cex = size, linlab)
         
-        if (axes) # coloca os eixos
-           abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
+        if (axes) abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
         
         if (axesvar) { # plota os eixos das variaveis
           
@@ -319,7 +309,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
                  text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
         }
         
-        if (savepicture) dev.off()
+        if (savptc) { box(col = 'white'); dev.off() }
         
         Sys.sleep(0.05) # tempo entre as plotagens dos graficos
         
@@ -329,7 +319,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
     }
     
-    if (savepicture) cat("\n \n End!")
+    if (savptc) message("\n \n End!")
     
   }
   
@@ -353,9 +343,9 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     a <- matrix(0, p, 1) # matriz de rotacao
     b <- matrix(0, p, 1) # matriz de rotacao
     
-    if (savepicture) {
-       cat("\014") # limpa a tela
-       cat("\n\n Saving graphics to hard disk. Wait for the end!")
+    if (savptc) {
+       message("\014") # limpa a tela
+       message("\n\n Saving graphics to hard disk. Wait for the end!")
     }
     
     numrot <- ifelse(is.na(choicerot[1]), numrot, choicerot)
@@ -380,7 +370,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
       if (is.na(choicerot[1]) || choicerot == i) {
         
-        if (savepicture) png(filename = paste("Picture ", i," - Method", method,".png",step="")) # salva os graficos em arquivos
+        if (savptc) png(filename = paste("Picture_", i,"-Method_", method,".png",sep=""), width = width, height = height, res = res) # salva os graficos em arquivos
         
         maxX = max(proj.data[, 1], A[,1])
         minX = min(proj.data[, 1], A[,1])
@@ -394,56 +384,34 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         }
         else { cor.classe <- c("blue") }
         
+        plot(proj.data, # coordenadas do grafico
+             xlab = xlabel, # Nomeia Eixo X
+             ylab = ylabel, # Nomeia Eixo Y
+             type = "n",    # nao plota pontos
+             main = Tit,    # Titulo para o grafico
+             xlim = c(minX,maxX), # dimensao eixo X
+             ylim = c(minY,maxY)) # dimensao eixo Y
+        
+        if (grid) {
+          
+          args <- append(as.list(par('usr')), c('gray93','gray93'))
+          
+          names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
+          
+          do.call(rect, args) # chama a funcao rect com os argumentos (args)
+          
+          grid(col = "white", lwd = 2, lty = 7, equilogs = T)
+          
+        }
+        
         if (Num.class == 0) {
-          
-           plot(proj.data, # coordenadas do grafico
-                xlab = xlabel, # Nomeia Eixo X
-                ylab = ylabel, # Nomeia Eixo Y
-                type = "n",    # nao plota pontos
-                main = Tit,    # Titulo para o grafico
-                xlim = c(minX,maxX), # dimensao eixo X
-                ylim = c(minY,maxY)) # dimensao eixo Y
-          
-           if (grid) {
-            
-              args <- append(as.list(par('usr')), c('gray93','gray93'))
-             
-              names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
-             
-              do.call(rect, args) # chama a funcao rect com os argumentos (args)
-             
-              grid(col = "white", lwd = 2, lty = 7, equilogs = T)
-            
-           }
-          
            points(proj.data, # coordenadas do grafico
                   pch  = 16,  # formato dos pontos
                   cex = size,  # Tamanho dos pontos 
                   col = ifelse(color, cor.classe, "Black"))
            
         } else {
-          
-          plot(0,0, # cria grafico para as coordenadas linhas x e colunas y
-               xlab = xlabel, # Nomeia Eixo X
-               ylab = ylabel, # Nomeia Eixo Y
-               main = Tit,    # Titulo
-               type = "n",    # nao plota pontos
-               xlim = c(minX,maxX), # dimensao eixo X
-               ylim = c(minY,maxY), # dimensao eixo Y
-               col  = ifelse(color,"red","black"))  # Cor dos pontos
-          
-          if (grid) {
-            
-             args <- append(as.list(par('usr')), c('gray93','gray93'))
-            
-             names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
-              
-             do.call(rect, args) # chama a funcao rect com os argumentos (args)
-            
-             grid(col = "white", lwd = 2, lty = 7, equilogs = T)
-            
-          } 
-          
+
           Init.Form <- 14 # formato inicial dos pontos
           
           for (k in 1:Num.class) {
@@ -467,8 +435,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         
         if (!is.na(linlab[1])) LocLab(proj.data, cex = size, linlab)
         
-        if (axes) # coloca os eixos
-           abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
+        if (axes) abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
         
         if (axesvar) { # plota os eixos das variaveis
           
@@ -505,7 +472,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
                  text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
         }
         
-        if (savepicture) dev.off()
+        if (savptc) { box(col = 'white'); dev.off() }
         
         Sys.sleep(0.05) # tempo entre as plotagens dos graficos
         
@@ -515,7 +482,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
     }
     
-    if (savepicture) cat("\n \n End!")
+    if (savptc) message("\n \n End!")
     
   }  
   
@@ -560,9 +527,9 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     
     numrot <- ifelse(is.na(choicerot[1]), numrot, choicerot)
     
-    if (savepicture) {
-       cat("\014") # limpa a tela 
-       cat("\n\n Saving graphics to hard disk. Wait for the end!")
+    if (savptc) {
+       message("\014") # limpa a tela 
+       message("\n\n Saving graphics to hard disk. Wait for the end!")
     }
     
     i <- 1  
@@ -575,7 +542,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
       
       if (is.na(choicerot[1]) || choicerot == i) {
         
-        if (savepicture) png(filename = paste("Picture ", i," - Method", method,".png",step="")) # salva os graficos em arquivos
+        if (savptc) png(filename = paste("Picture_", i,"-Method_", method,".png",sep=""), width = width, height = height, res = res) # salva os graficos em arquivos
         
         maxX = max(proj.data[, 1])
         minX = min(proj.data[, 1])
@@ -589,56 +556,34 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         }
         else { cor.classe <- c("blue") }
         
+        plot(proj.data, # coordenadas do grafico
+             xlab = xlabel, # Nomeia Eixo X
+             ylab = ylabel, # Nomeia Eixo Y
+             type = "n",    # nao plota pontos
+             main = Tit,    # Titulo para o grafico
+             xlim = c(minX,maxX), # dimensao eixo X
+             ylim = c(minY,maxY)) # dimensao eixo Y
+        
+        if (grid) {
+          
+          args <- append(as.list(par('usr')), c('gray93','gray93'))
+          
+          names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
+          
+          do.call(rect, args) # chama a funcao rect com os argumentos (args)
+          
+          grid(col = "white", lwd = 2, lty = 7, equilogs = T)
+          
+        }
+        
         if (Num.class == 0) {
-          
-           plot(proj.data, # coordenadas do grafico
-                xlab = xlabel, # Nomeia Eixo X
-                ylab = ylabel, # Nomeia Eixo Y
-                type = "n",    # nao plota pontos
-                main = Tit,    # Titulo para o grafico
-                xlim = c(minX,maxX), # dimensao eixo X
-                ylim = c(minY,maxY)) # dimensao eixo Y
-          
-           if (grid) {
-            
-              args <- append(as.list(par('usr')), c('gray93','gray93'))
-             
-              names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
-             
-              do.call(rect, args) # chama a funcao rect com os argumentos (args)
-             
-              grid(col = "white", lwd = 2, lty = 7, equilogs = T)
-            
-           }
-          
            points(proj.data, # coordenadas do grafico
                   pch  = 16,  # formato dos pontos
                   cex = size,  # Tamanho dos pontos 
                   col = ifelse(color, cor.classe, "Black"))
           
         } else {
-          
-          plot(0,0, # cria grafico para as coordenadas linhas x e colunas y
-               xlab = xlabel, # Nomeia Eixo X
-               ylab = ylabel, # Nomeia Eixo Y
-               main = Tit,    # Titulo
-               type = "n",    # nao plota pontos
-               xlim = c(minX,maxX), # dimensao eixo X
-               ylim = c(minY,maxY)) # dimensao eixo Y
-               # col  = ifelse(color,"red","black"))  # Cor dos pontos
-          
-          if (grid) {
-            
-             args <- append(as.list(par('usr')), c('gray93','gray93'))
-            
-             names(args) <- c('xleft', 'xright', 'ybottom', 'ytop', 'col', 'border')
-            
-             do.call(rect, args) # chama a funcao rect com os argumentos (args)
-            
-             grid(col = "white", lwd = 2, lty = 7, equilogs = T)
-            
-          } 
-          
+
           Init.Form <- 14 # formato inicial dos pontos
           
           for (k in 1:Num.class) {
@@ -662,8 +607,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
         
         if (!is.na(linlab[1])) LocLab(proj.data[1:n,], cex = size, linlab)
         
-        if (axes) # coloca os eixos
-           abline(h = 0, v=0, cex = 1.5, lty=2) # cria o eixo central
+        if (axes) abline(h = 0, v = 0, cex = 1.5, lty = 2) # cria o eixo central
         
         if (axesvar) { # plota os eixos das variaveis
           
@@ -697,7 +641,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
                  text.col = color_b, bty = boxleg, text.font = 6, y.intersp = 0.8, xpd = TRUE) # cria a legenda
         }
         
-        if (savepicture) dev.off()
+        if (savptc) { box(col = 'white'); dev.off() }
         
         Sys.sleep(0.05) # tempo entre as plotagens dos graficos
         
@@ -711,7 +655,7 @@ GrandTour <- function(data, method = "Interpolation", title = NA, xlabel = NA, y
     
     proj.data <- proj.data[1:n,1:d] # dados projetados
     
-    if (savepicture) cat("\n \n End!")
+    if (savptc) message("\n \n End!")
     
   }
   
